summaryrefslogtreecommitdiffstats
path: root/src/datavisualization/data/qitemmodelsurfacedataproxy.cpp
diff options
context:
space:
mode:
authorTomi Korpipaa <tomi.korpipaa@qt.io>2020-12-10 07:12:10 +0200
committerTomi Korpipaa <tomi.korpipaa@qt.io>2020-12-14 06:57:52 +0200
commit471a6cbd07fddd3f392204d532ac8d3639c7dc7f (patch)
treecd4aa8b6cda0bb52e851d7ced1a3a93b8a8fa622 /src/datavisualization/data/qitemmodelsurfacedataproxy.cpp
parent058eab02a5c1d8d8de8917d473eb39aa18a1c888 (diff)
Migrate C++ API rendering path to Qt 6
Replace QRegExp with QRegularExpression and change usage accordingly. Replace shared QOpenGLFunctions_2_1 with our own copy. Fix header include changes. Task-number: QTBUG-89297 Change-Id: I6d3cf36ba9303ef62db3220816ea35f51eb26a3c Reviewed-by: Miikka Heikkinen <miikka.heikkinen@qt.io>
Diffstat (limited to 'src/datavisualization/data/qitemmodelsurfacedataproxy.cpp')
-rw-r--r--src/datavisualization/data/qitemmodelsurfacedataproxy.cpp42
1 files changed, 21 insertions, 21 deletions
diff --git a/src/datavisualization/data/qitemmodelsurfacedataproxy.cpp b/src/datavisualization/data/qitemmodelsurfacedataproxy.cpp
index 47230326..0fa50fb2 100644
--- a/src/datavisualization/data/qitemmodelsurfacedataproxy.cpp
+++ b/src/datavisualization/data/qitemmodelsurfacedataproxy.cpp
@@ -82,7 +82,7 @@ QT_BEGIN_NAMESPACE_DATAVISUALIZATION
* If the fields of the model do not contain the data in the exact format you need, you can specify
* a search pattern regular expression and a replace rule for each role to get the value in a
* format you need. For more information how the replace using regular expressions works, see
* QString::replace(const QRegExp &rx, const QString &after) function documentation. Note that
* using regular expressions has an impact on the performance, so it's more efficient to utilize
* item models where doing search and replace is not necessary to get the desired values.
*
@@ -251,7 +251,7 @@ QT_BEGIN_NAMESPACE_DATAVISUALIZATION
* The replace content to be used in conjunction with rowRolePattern.
* Defaults to an empty string. For more information on how the search and
* replace using regular expressions works, see the
* QString::replace(const QRegExp &rx, const QString &after)
* function documentation.
*
* \sa rowRole, rowRolePattern
@@ -263,7 +263,7 @@ QT_BEGIN_NAMESPACE_DATAVISUALIZATION
* The replace content to be used in conjunction with columnRolePattern.
* Defaults to an empty string. For more information on how the search and
* replace using regular expressions works, see the
* QString::replace(const QRegExp &rx, const QString &after)
* function documentation.
*
* \sa columnRole, columnRolePattern
@@ -275,7 +275,7 @@ QT_BEGIN_NAMESPACE_DATAVISUALIZATION
* The replace content to be used in conjunction with xPosRolePattern.
* Defaults to an empty string. For more information on how the search and
* replace using regular expressions works, see the
* QString::replace(const QRegExp &rx, const QString &after)
* function documentation.
*
* \sa xPosRole, xPosRolePattern
@@ -287,7 +287,7 @@ QT_BEGIN_NAMESPACE_DATAVISUALIZATION
* The replace content to be used in conjunction with yPosRolePattern.
* Defaults to an empty string. For more information on how the search and
* replace using regular expressions works, see the
* QString::replace(const QRegExp &rx, const QString &after)
* function documentation.
*
* \sa yPosRole, yPosRolePattern
@@ -299,7 +299,7 @@ QT_BEGIN_NAMESPACE_DATAVISUALIZATION
* The replace content to be used in conjunction with zPosRolePattern.
* Defaults to an empty string. For more information on how the search and
* replace using regular expressions works, see the
* QString::replace(const QRegExp &rx, const QString &after)
* function documentation.
*
* \sa zPosRole, zPosRolePattern
@@ -770,7 +770,7 @@ int QItemModelSurfaceDataProxy::columnCategoryIndex(const QString &category)
*
* \sa rowRole, rowRoleReplace
*/
-void QItemModelSurfaceDataProxy::setRowRolePattern(const QRegExp &pattern)
+void QItemModelSurfaceDataProxy::setRowRolePattern(const QRegularExpression &pattern)
{
if (dptr()->m_rowRolePattern != pattern) {
dptr()->m_rowRolePattern = pattern;
@@ -778,7 +778,7 @@ void QItemModelSurfaceDataProxy::setRowRolePattern(const QRegExp &pattern)
}
}
-QRegExp QItemModelSurfaceDataProxy::rowRolePattern() const
+QRegularExpression QItemModelSurfaceDataProxy::rowRolePattern() const
{
return dptrc()->m_rowRolePattern;
}
@@ -795,7 +795,7 @@ QRegExp QItemModelSurfaceDataProxy::rowRolePattern() const
*
* \sa columnRole, columnRoleReplace
*/
-void QItemModelSurfaceDataProxy::setColumnRolePattern(const QRegExp &pattern)
+void QItemModelSurfaceDataProxy::setColumnRolePattern(const QRegularExpression &pattern)
{
if (dptr()->m_columnRolePattern != pattern) {
dptr()->m_columnRolePattern = pattern;
@@ -803,7 +803,7 @@ void QItemModelSurfaceDataProxy::setColumnRolePattern(const QRegExp &pattern)
}
}
-QRegExp QItemModelSurfaceDataProxy::columnRolePattern() const
+QRegularExpression QItemModelSurfaceDataProxy::columnRolePattern() const
{
return dptrc()->m_columnRolePattern;
}
@@ -820,7 +820,7 @@ QRegExp QItemModelSurfaceDataProxy::columnRolePattern() const
*
* \sa xPosRole, xPosRoleReplace
*/
-void QItemModelSurfaceDataProxy::setXPosRolePattern(const QRegExp &pattern)
+void QItemModelSurfaceDataProxy::setXPosRolePattern(const QRegularExpression &pattern)
{
if (dptr()->m_xPosRolePattern != pattern) {
dptr()->m_xPosRolePattern = pattern;
@@ -828,7 +828,7 @@ void QItemModelSurfaceDataProxy::setXPosRolePattern(const QRegExp &pattern)
}
}
-QRegExp QItemModelSurfaceDataProxy::xPosRolePattern() const
+QRegularExpression QItemModelSurfaceDataProxy::xPosRolePattern() const
{
return dptrc()->m_xPosRolePattern;
}
@@ -845,7 +845,7 @@ QRegExp QItemModelSurfaceDataProxy::xPosRolePattern() const
*
* \sa yPosRole, yPosRoleReplace
*/
-void QItemModelSurfaceDataProxy::setYPosRolePattern(const QRegExp &pattern)
+void QItemModelSurfaceDataProxy::setYPosRolePattern(const QRegularExpression &pattern)
{
if (dptr()->m_yPosRolePattern != pattern) {
dptr()->m_yPosRolePattern = pattern;
@@ -853,7 +853,7 @@ void QItemModelSurfaceDataProxy::setYPosRolePattern(const QRegExp &pattern)
}
}
-QRegExp QItemModelSurfaceDataProxy::yPosRolePattern() const
+QRegularExpression QItemModelSurfaceDataProxy::yPosRolePattern() const
{
return dptrc()->m_yPosRolePattern;
}
@@ -870,7 +870,7 @@ QRegExp QItemModelSurfaceDataProxy::yPosRolePattern() const
*
* \sa zPosRole, zPosRoleReplace
*/
-void QItemModelSurfaceDataProxy::setZPosRolePattern(const QRegExp &pattern)
+void QItemModelSurfaceDataProxy::setZPosRolePattern(const QRegularExpression &pattern)
{
if (dptr()->m_zPosRolePattern != pattern) {
dptr()->m_zPosRolePattern = pattern;
@@ -878,7 +878,7 @@ void QItemModelSurfaceDataProxy::setZPosRolePattern(const QRegExp &pattern)
}
}
-QRegExp QItemModelSurfaceDataProxy::zPosRolePattern() const
+QRegularExpression QItemModelSurfaceDataProxy::zPosRolePattern() const
{
return dptrc()->m_zPosRolePattern;
}
@@ -890,7 +890,7 @@ QRegExp QItemModelSurfaceDataProxy::zPosRolePattern() const
* pattern.
*
* Defaults to an empty string. For more information on how the search and replace using regular
* expressions works, see QString::replace(const QRegExp &rx, const QString &after)
* function documentation.
*
* \sa rowRole, rowRolePattern
@@ -916,7 +916,7 @@ QString QItemModelSurfaceDataProxy::rowRoleReplace() const
*
* Defaults to an empty string. For more information on how the search and
* replace using regular expressions works, see the
* QString::replace(const QRegExp &rx, const QString &after)
* function documentation.
*
* \sa columnRole, columnRolePattern
@@ -942,7 +942,7 @@ QString QItemModelSurfaceDataProxy::columnRoleReplace() const
*
* Defaults to an empty string. For more information on how the search and
* replace using regular expressions works, see the
* QString::replace(const QRegExp &rx, const QString &after)
* function documentation.
*
* \sa xPosRole, xPosRolePattern
@@ -968,7 +968,7 @@ QString QItemModelSurfaceDataProxy::xPosRoleReplace() const
*
* Defaults to an empty string. For more information on how the search and
* replace using regular expressions works, see the
* QString::replace(const QRegExp &rx, const QString &after)
* function documentation.
*
* \sa yPosRole, yPosRolePattern
@@ -994,7 +994,7 @@ QString QItemModelSurfaceDataProxy::yPosRoleReplace() const
*
* Defaults to an empty string. For more information on how the search and
* replace using regular expressions works, see the
* QString::replace(const QRegExp &rx, const QString &after)
* function documentation.
*
* \sa zPosRole, zPosRolePattern
@@ -82,7 +82,7 @@ QT_BEGIN_NAMESPACE_DATAVISUALIZATION
* a search pattern regular expression and a replace rule for each role to get the value in a
* format you need. For more information how the replace using regular expressions works, see
- * QString::replace(const QRegExp &rx, const QString &after) function documentation. Note that
+ * QString::replace(const QRegularExpression &rx, const QString &after) function documentation. Note that
* using regular expressions has an impact on the performance, so it's more efficient to utilize
* item models where doing search and replace is not necessary to get the desired values.
@@ -251,7 +251,7 @@ QT_BEGIN_NAMESPACE_DATAVISUALIZATION
* Defaults to an empty string. For more information on how the search and
* replace using regular expressions works, see the
- * QString::replace(const QRegExp &rx, const QString &after)
+ * QString::replace(const QRegularExpression &rx, const QString &after)
* function documentation.
*
@@ -263,7 +263,7 @@ QT_BEGIN_NAMESPACE_DATAVISUALIZATION
* Defaults to an empty string. For more information on how the search and
* replace using regular expressions works, see the
- * QString::replace(const QRegExp &rx, const QString &after)
+ * QString::replace(const QRegularExpression &rx, const QString &after)
* function documentation.
*
@@ -275,7 +275,7 @@ QT_BEGIN_NAMESPACE_DATAVISUALIZATION
* Defaults to an empty string. For more information on how the search and
* replace using regular expressions works, see the
- * QString::replace(const QRegExp &rx, const QString &after)
+ * QString::replace(const QRegularExpression &rx, const QString &after)
* function documentation.
*
@@ -287,7 +287,7 @@ QT_BEGIN_NAMESPACE_DATAVISUALIZATION
* Defaults to an empty string. For more information on how the search and
* replace using regular expressions works, see the
- * QString::replace(const QRegExp &rx, const QString &after)
+ * QString::replace(const QRegularExpression &rx, const QString &after)
* function documentation.
*
@@ -299,7 +299,7 @@ QT_BEGIN_NAMESPACE_DATAVISUALIZATION
* Defaults to an empty string. For more information on how the search and
* replace using regular expressions works, see the
- * QString::replace(const QRegExp &rx, const QString &after)
+ * QString::replace(const QRegularExpression &rx, const QString &after)
* function documentation.
*
@@ -890,7 +890,7 @@ QRegExp QItemModelSurfaceDataProxy::zPosRolePattern() const
*
* Defaults to an empty string. For more information on how the search and replace using regular
- * expressions works, see QString::replace(const QRegExp &rx, const QString &after)
+ * expressions works, see QString::replace(const QRegularExpression &rx, const QString &after)
* function documentation.
*
@@ -916,7 +916,7 @@ QString QItemModelSurfaceDataProxy::rowRoleReplace() const
* Defaults to an empty string. For more information on how the search and
* replace using regular expressions works, see the
- * QString::replace(const QRegExp &rx, const QString &after)
+ * QString::replace(const QRegularExpression &rx, const QString &after)
* function documentation.
*
@@ -942,7 +942,7 @@ QString QItemModelSurfaceDataProxy::columnRoleReplace() const
* Defaults to an empty string. For more information on how the search and
* replace using regular expressions works, see the
- * QString::replace(const QRegExp &rx, const QString &after)
+ * QString::replace(const QRegularExpression &rx, const QString &after)
* function documentation.
*
@@ -968,7 +968,7 @@ QString QItemModelSurfaceDataProxy::xPosRoleReplace() const
* Defaults to an empty string. For more information on how the search and
* replace using regular expressions works, see the
- * QString::replace(const QRegExp &rx, const QString &after)
+ * QString::replace(const QRegularExpression &rx, const QString &after)
* function documentation.
*
@@ -994,7 +994,7 @@ QString QItemModelSurfaceDataProxy::yPosRoleReplace() const
* Defaults to an empty string. For more information on how the search and
* replace using regular expressions works, see the
- * QString::replace(const QRegExp &rx, const QString &after)
+ * QString::replace(const QRegularExpression &rx, const QString &after)
* function documentation.
*